@@ -1,13 +1,17 @@
+import ibis.expr.operations as ops
+
 IBIS_SUBSTRAIT_OP_MAPPING = {
-    "Add": "+",  # wrong but using for duckdb compatibility right now
+    "Add": "add",
     "And": "and",
     "Any": "any",
     "Between": "between",
     "Count": "count",
     "CountDistinct": "countdistinct",
-    "Divide": "/",  # wrong but using for duckdb compatibility right now
+    "Divide": "divide",
     "Equals": "equal",
-    "ExtractYear": "extractyear",
+    "ExtractYear": "extract",
+    "ExtractMonth": "extract",
+    "ExtractDay": "extract",
     "Greater": "gt",
     "GreaterEqual": "gte",
     "Less": "lt",
@@ -15,15 +19,21 @@ IBIS_SUBSTRAIT_OP_MAPPING = {
     "Max": "max",
     "Mean": "mean",
     "Min": "min",
-    "Multiply": "*",  # wrong but using for duckdb compatibility right now
+    "Multiply": "multiply",
     "Not": "not",
     "NotEquals": "not_equal",
     "Or": "or",
     "StringLength": "string_length",  # don't know
     "StringSQLLike": "like",
     "Substring": "substring",
-    "Subtract": "-",  # wrong but using for duckdb compatibility right now
+    "Subtract": "subtract",
     "Sum": "sum",
 }
 
-SUBSTRAIT_IBIS_OP_MAPPING = {v: k for k, v in IBIS_SUBSTRAIT_OP_MAPPING.items()}
+SUBSTRAIT_IBIS_OP_MAPPING = {
+    v: getattr(ops, k) for k, v in IBIS_SUBSTRAIT_OP_MAPPING.items()
+}
+# override when reversing many-to-one mappings
+SUBSTRAIT_IBIS_OP_MAPPING["extract"] = lambda table, span: getattr(
+    ops, f"Extract{span.capitalize()}"
+)(table)
